@@ -619,7 +619,9 @@ static void *plusequals_new(t_floatarg f)
 //////// Cyclone object
 
 typedef struct cyclone{
-    t_object x_obj;
+    t_object  x_obj;
+    t_outlet *x_out2;
+    t_outlet *x_out3;
 }t_cyclone;
 
 t_class *cyclone_class;
@@ -627,11 +629,11 @@ t_class *cyclone_class;
 static int printed;
 
 static int min_major = 0;
-static int min_minor = 53;
-static int min_bugfix = 2;
+static int min_minor = 55;
+static int min_bugfix = 0;
 
 static int cyclone_major = 0;
-static int cyclone_minor = 7;
+static int cyclone_minor = 9;
 static int cyclone_bugfix = 0;
 
 void print_cyclone(t_cyclone *x){
@@ -639,9 +641,9 @@ void print_cyclone(t_cyclone *x){
     sys_getversion(&major, &minor, &bugfix);
     post("");
     post("--------------------------------------------------------------------");
-    post(":: Cyclone %d.%d-%d; Released february 21st 2023", cyclone_major, cyclone_minor, cyclone_bugfix);
+    post(":: Cyclone %d.%d-%d; Released June 23rd 2024", cyclone_major, cyclone_minor, cyclone_bugfix);
     post(":: License: BSD-3-Clause (aka Revised BSD License)");
-    post(":: Copyright © 2003-2021 - Krzysztof Czaja, Hans-Christoph Steiner,");
+    post(":: Copyright © 2003-2024 - Krzysztof Czaja, Hans-Christoph Steiner,");
     post(":: Fred Jan Kraan, Alexandre Porres, Derek Kwan, Matt Barber\n\:: and others.");
     post(":: -----------------------------------------------------------------");
     if((major > min_major)
@@ -663,6 +665,10 @@ void print_cyclone(t_cyclone *x){
     post(":: you need to add 'cyclone' to the \"preferences=>path\"");
     post(":: or use [declare -path cyclone] (this guarantees search priority)");
     post("--------------------------------------------------------------------");
+    post("-------------------------------------------------------------------");
+    post("- NOTE: Loading this binary did install an object browser");
+    post("plugin for Cyclone objects when right clicking on a canvas.");
+    post("-------------------------------------------------------------------");
     post("");
 }
 
@@ -673,13 +679,31 @@ static void cyclone_about(t_cyclone *x){
 static void cyclone_version(t_cyclone *x){
     int ac = 3;
     t_atom at[ac];
+#ifdef PD_FLAVOR
+    SETSYMBOL(at, gensym(PD_FLAVOR));
+#ifdef PD_L2ORK_VERSION
+    SETSYMBOL(at+1, gensym(PD_L2ORK_VERSION));
+#elif defined(PD_PLUGDATA_VERSION)
+    SETSYMBOL(at+1, gensym(PD_PLUGDATA_VERSION));
+#endif
+    outlet_list(x->x_out3,  &s_list, 2, at);
+#else
+    outlet_symbol(x->x_out3, gensym("Pd-Vanilla"));
+#endif
+    
+    int major = 0, minor = 0, bugfix = 0;
+    sys_getversion(&major, &minor, &bugfix);
+    SETFLOAT(at+0, major);
+    SETFLOAT(at+1, minor);
+    SETFLOAT(at+2, bugfix);
+    outlet_list(x->x_out2,  &s_list, ac, at);
+    
     SETFLOAT(at, cyclone_major);
     SETFLOAT(at+1, cyclone_minor);
     SETFLOAT(at+2, cyclone_bugfix);
     outlet_list(x->x_obj.te_outlet,  &s_list, ac, at);
 }
 
-
 static void *cyclone_new(void){
     t_cyclone *x = (t_cyclone *)pd_new(cyclone_class);
     if(!printed){
@@ -687,6 +711,8 @@ static void *cyclone_new(void){
         printed = 1;
     }
     outlet_new((t_object *)x, 0);
+    x->x_out2 = outlet_new((t_object *)x, &s_list);
+    x->x_out3 = outlet_new((t_object *)x, &s_list);
     return(x);
 }
 
@@ -830,6 +856,10 @@ CYCLONE_API void cyclone_setup(void)
     class_addbang(plusequals_class, plusequals_bang);
     class_addmethod(plusequals_class, (t_method)plusequals_set, gensym("set"), A_FLOAT, 0);
     class_sethelpsymbol(plusequals_class, gensym("plusequals~"));
+    
+    char plugin[MAXPDSTRING];
+    sprintf(plugin, "%s/browser-cyclone.tcl", cyclone_class->c_externdir->s_name);
+    pdgui_vmess("load_plugin_script", "s", plugin);
 
 #if CYCLONE_SINGLE_LIBRARY
     setup_single_lib();
